@@ -9,5 +9,5 @@
 import Foundation
 
 protocol NetworkSession {
-    func loadData(from url: URL) async throws -> (Data, URLResponse)
+	func data(from url: URL) async throws -> (Data, URLResponse)
 }
